API
===

eth\_abi.abi module
-------------------

.. automodule:: eth_abi_lite.abi
    :members:
    :undoc-members:
    :show-inheritance:

eth\_abi.base module
--------------------

.. automodule:: eth_abi_lite.base
    :members: BaseCoder
    :show-inheritance:

eth\_abi.codec module
---------------------

.. automodule:: eth_abi_lite.codec
    :members:
    :undoc-members:
    :show-inheritance:

eth\_abi.decoding module
------------------------

.. automodule:: eth_abi_lite.decoding
    :members: BaseDecoder
    :show-inheritance:

eth\_abi.encoding module
------------------------

.. automodule:: eth_abi_lite.encoding
    :members: BaseEncoder
    :show-inheritance:

eth\_abi.exceptions module
--------------------------

.. automodule:: eth_abi_lite.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

eth\_abi.registry module
------------------------

.. automodule:: eth_abi_lite.registry

    .. autoclass:: ABIRegistry
        :members:

eth\_abi.grammar module
-----------------------

.. automodule:: eth_abi_lite.grammar

    .. autoclass:: ABIType
        :members:
    .. autoclass:: TupleType
        :members:
    .. autoclass:: BasicType
        :members:
    .. autofunction:: normalize
    .. autofunction:: parse(type_str)

eth\_abi.tools module
---------------------

.. automodule:: eth_abi_lite.tools

    .. autofunction:: get_abi_strategy
